@@ -5,6 +5,6 @@ https://community.openglow.org
 
 SPDX-License-Identifier:    MIT
 """
-from gfutilities.puls.pulsedata import decode_all_steps
+from gfutilities.puls.pulsedata import decode_all_steps, generate_linear_puls
 
-__all__ = ['decode_all_steps']
+__all__ = ['decode_all_steps', 'generate_linear_puls']
